package fr.sanchezm.attestationsCovid19.data.repository

import fr.sanchezm.attestationsCovid19.data.db.dao.AttestationDao
import fr.sanchezm.attestationsCovid19.data.db.entity.Attestation
import fr.sanchezm.attestationsCovid19.utilities.PdfUtils

class AttestationRepository private constructor(private val attestationDao: AttestationDao) {

    fun generateAttestation(attestation: Attestation, callback: (Boolean) -> Unit) =
        PdfUtils.getInstance()?.fillForm(attestation, callback)

    fun getAttestations() = attestationDao.getAttestations()

    fun getAttestation(id: Int) = attestationDao.getAttestation(id)

    fun getAttestation(createAt: Long) = attestationDao.getAttestation(createAt)

    fun addAttestation(attestation: Attestation) = attestationDao.addAttestation(attestation)

    fun deleteAttestation(attestation: Attestation) = attestationDao.deleteAttestation(attestation)

    companion object {
        @Volatile
        private var instance: AttestationRepository? = null

        fun getInstance(attestationDao: AttestationDao) =
            instance ?: synchronized(this) {
                instance ?: AttestationRepository(attestationDao).also { instance = it }
            }
    }
}