package fr.sanchezm.attestationsCovid19.ui.qrcode

import android.graphics.Bitmap
import android.view.View
import androidx.lifecycle.LiveData
import androidx.lifecycle.MutableLiveData
import androidx.lifecycle.ViewModel
import fr.sanchezm.attestationsCovid19.data.db.entity.Attestation
import fr.sanchezm.attestationsCovid19.data.repository.AttestationRepository
import fr.sanchezm.attestationsCovid19.utilities.Event
import fr.sanchezm.attestationsCovid19.utilities.QRCodeUtils

class QrCodeViewModel(private val attestationRepository: AttestationRepository) : ViewModel() {

    private val _attestation = MutableLiveData<Attestation>()

    private val _loading = MutableLiveData(View.GONE)
    private val _displayQrCode = MutableLiveData(View.GONE)
    private val _qrCodeBitmap = MutableLiveData<Bitmap>()
    private val _peopleItem = MutableLiveData<String>()
    private val _dateItem = MutableLiveData<String>()
    private val _reasonItem = MutableLiveData<String>()

    private val _startActivity = MutableLiveData<Event<Long>>()
    private val _finish = MutableLiveData<Event<Boolean>>()

    val attestation: LiveData<Attestation> = _attestation

    val loading: LiveData<Int> = _loading
    val displayQrCode: LiveData<Int> = _displayQrCode
    val qrCodeBitmap: LiveData<Bitmap> = _qrCodeBitmap
    val peopleItem: LiveData<String> = _peopleItem
    val dateItem: LiveData<String> = _dateItem
    val reasonItem: LiveData<String> = _reasonItem

    val startActivity: LiveData<Event<Long>> = _startActivity
    val finish: LiveData<Event<Boolean>> = _finish

    fun addData(createAt: Long, toCreate: Boolean) {
        val att = attestationRepository.getAttestation(createAt)

        _attestation.value = att
        if (toCreate) {
            _loading.value = View.VISIBLE
            createPdf()
        } else {
            displayQrCode()
        }
    }

    fun displayAttestation() {
        _startActivity.value = Event(_attestation.value!!.createAt)
    }

    fun deleteAttestation() {
        attestationRepository.deleteAttestation(_attestation.value!!)
        _finish.value = Event(true)
    }

    private fun createPdf() {
        _attestation.value?.let { attesattion ->
            attestationRepository.generateAttestation(
                attesattion
            ) { success ->
                if (success)
                    displayQrCode()
            }
        }
    }

    private fun displayQrCode() {
        _qrCodeBitmap.value = _attestation.value?.let { QRCodeUtils.getQrCode(it, 300) }

        _peopleItem.value = attestation.value?.getNameFormatted()
        _dateItem.value = attestation.value?.getExitDateFormatted()
        _reasonItem.value = attestation.value?.getMotifsFormatted()

        _loading.value = View.GONE
        _displayQrCode.value = View.VISIBLE
    }

    companion object {
        private val TAG = QrCodeViewModel::class.simpleName
    }
}
