package fr.sanchezm.attestationsCovid19.utilities

import android.content.Context
import android.os.Environment
import fr.sanchezm.attestationsCovid19.data.db.MyDatabase
import fr.sanchezm.attestationsCovid19.data.repository.AttestationRepository
import fr.sanchezm.attestationsCovid19.data.repository.ProfileRepository
import fr.sanchezm.attestationsCovid19.ui.add.AddViewModelFactory
import fr.sanchezm.attestationsCovid19.ui.attestations.AttestationsViewModelFactory
import fr.sanchezm.attestationsCovid19.ui.qrcode.QrCodeViewModelFactory

object InjectorUtils {

    fun provideAddViewModelFactory(context: Context): AddViewModelFactory {
        val profileRepository =
            ProfileRepository.getInstance(
                MyDatabase.invoke(context, getMyFilesDir(context)).profileDao()
            )
        val attestationRepository =
            AttestationRepository.getInstance(
                MyDatabase.invoke(context, getMyFilesDir(context)).attestationDao()
            )

        return AddViewModelFactory(profileRepository, attestationRepository)
    }

    fun provideAttestationViewModel(context: Context): AttestationsViewModelFactory {
        val attestationRepository =
            AttestationRepository.getInstance(
                MyDatabase.invoke(context, getMyFilesDir(context)).attestationDao()
            )

        return AttestationsViewModelFactory(attestationRepository)
    }

    fun provideQrCodeViewModel(context: Context): QrCodeViewModelFactory {
        val attestationRepository =
            AttestationRepository.getInstance(
                MyDatabase.invoke(context, getMyFilesDir(context)).attestationDao()
            )

        return QrCodeViewModelFactory(attestationRepository)
    }

    fun providePdfUtils(context: Context): PdfUtils {
        return PdfUtils.getInstance(context.assets, getMyFilesDir(context))
    }

    private fun getMyFilesDir(context: Context): String = context.getExternalFilesDir(Environment.DIRECTORY_DOWNLOADS)?.path!!

}